# Finite subgroups of SO(3) and the restrictions they place on the distribution of hole-adjacent edges in p-cages

This repository contains code for the study of symmetric p-cages, written for our paper, B.M.A.G. Piette and Á. Lukács, Near-miss symmetric polyhedral cages.

These programs calculate the subgroups of the symmetry group of p-cages, list the ones that act transitively on the faces of the cage, and verify the constraints the symmetries place on the number of hole-adjacent edges.

## Definitions

A <i>p-cage</i> is an object consisting of polygons glued together on some of their edges. The polygons are the <i>faces</i> of the p-cage. It is assumed that of any two edges of a face at least one of them is not shared by two polygons. As a result, there are also <i>holes</i> between the faces of a p-cage. It is assumed that all faces share and edge with at least three other faces, which are termed their <i>neighbours</i>.

The <i>hole polyhedron</i> is the dual of a p-cage in the same sense as polyhedra have duals: to each face of the cage a vertex of the hole polyhedron is assigned, and two vertices are connected in the hole polyhedron if the corresponding faces are neighbours.

The faces of the hole polyhedron correspond to the holes of the p-cage. At each vertex, between two edges, we may add a <i>label</i> <i>q<sub>i</sub></i> denoting the number of edges on the face corresponding to the vertex shared with the hole corresponding to the given face of the hole polyhedron.

For more details, see A. Kowalczyk, B.M.A.G. Piette, and J.G. Heddle, Characterization of near-miss connectivity-invariant homogeneous convex polyhedral cages, <i>Proc. Roy. Soc. A.</i> <b>478</b> 20210679 (2022).

A p-cage is <i>homogeneous</i> if its group of symmetries can map any of its faces onto any other. Symmetries may be <i>combinatorial</i> or <i>congruent</i> whether they are symmetries of the connectivity structure (including also the labels), or congruences (isometries) of the 3d Euclidean space. In this work, we consider congruences.

## Aims

For a congruent homogeneous p-cage, the hole polyhedron must have a transitive symmetry group. This group is a finite subgroup of the <i>SO(3)</i> rotation group. It also acts as a permutation group on the vertices of the hole polyhedron.

We shall consider here Platonic and Archimedean solids as hole polyhedra.  In each case, the symmetry of the solid will be called the <i>full symmetry group</i>. Deformations or the labelling may violate some of the symmetries, however, the group remaining must still be transitive. Therefore, our code finds the transitive subgroups of the full group.

If there are multiple isomorphic subgroups, we verify if they are conjugate, and of these, only consider one. Two conjugate subgroups are considered the same, as they are the symmetries of the same object, looking at it from a different orientation.

For each transitive subgroup, we consider the constraints it places on the labelling, by labelling around one vertex of the hole polyhedron, extending the labelling to all other vertices, and keeping track of <i>label clashes</i>, i.e., when different labels can be moved to the same place with the help of the symmetry group. The consequence of a label clash is that the clashing labels must be equal.

## Implementation


The code here consists of input files for the computer algebra system GAP. It has been tested using GAP 4.10.2.

The name of the file corresponds to the hole-polyhedron of the p-cage considered. 

To run any of the programs, simply type `gap < filename`, e.g., `gap < cube_symm.g` to determine the symmetries of a p-cage with the cube as its hole-polyhedron.

List of scripts:
 * `tetra_symm.g` tetrahedron hole-polyhedron
 * `cube_symm_1.g` cube hole-polyhedron, D8 subgroup
 * `cube_symm_2.g` cube hole-polyhedron, full group
 * `octa_symm_1.g` octahedron hole-polyhedron, A4 subgroup
 * `octa_symm_2.g` octahedron pole-polyhedron, full group
 * `dodeca_symm.g` dodecahedron hole-polyhedron
 * `icosa_symm_1.g` icosahedron hole-polyhedron, A4 subgroup
 * `icosa_symm_2.g` icosahedron hole-polyhedron, full group
 * `trunc_tetra_symm.g` truncated tetrahedron hole-polyhedron
 * `trunc_cube_symm.g` truncated cube hole-polyhedron
 * `trunc_octa_symm.g` truncated octahedron hole-polyhedron
 * `trunc_dodeca_symm.g` truncated dodecahedron hole-polyhedron
 * `trunc_icosa_symm.g` truncated icosahedron hole-polyhedron
 * `cubocta_symm_1.g` cuboctahedron hole-polyhedron, A4 subgroup
 * `cubocta_symm_2.g` cuboctahedron hole-polyhedron, full subgroup
 * `rhombicubocta_symm.g` rhombicuboctahedron hole-polyhedron
 * `snub_cube_symm.g` snub cube hole-polyhedron
 * `icosidodeca_symm.g` icosidodecahedron hole-polyhedron
 * `rhombicosidodeca_symm.g` rhombicosidodecahedron hole-polyhedron
 * `snub_dodeca_symm.g` snub dodecahedron hole-polyhedron

## Output

The output of each of the scripts is the list of the subgroups of the symmetry group of a given hole polyhedra. After that, if there are multiple subgroups of the same type, it is verified if they are conjugate.

After the list of the subgroups, one is selected, and a labelling is performed, keeping track of label clashes. In the end, there is a list of clashing labels, and for each label, the places where the same label is placed is printed.

The output format is as follows: group elements are represented as permutations of the vertices of the hole polyhedra, in the cycle notation of GAP. Groups, subgroups, etc., are printed in the notation of GAP, either with a list of their elements or with generators.

Labels are printed as triplets of vertices: a label <i>[i, j, k]</i> means the one at vertex <i>j</i> between the edges connecting vertex <i>j</i> to vertices <i>i</i> and <i>k</i>.

Label clashes are printed as pairs of labels that clash somewhere. The code prints pairs of labels that need to be equal (clash). This must be transitive.

## How the code works

Then the action of the symmetry group of the hole polyhedron as a permutation group acting on the vertices of the hole polyhedron is considered. The code then proceeds to determine which of the subgroups of the symmetry group act transitively. If there are multiple transitive subgroups, a number is added to the file name. Each file then proceeds to determine the restrictions placed on the distribution of hole-adjacent edges on the faces of the p-cage, termed label clashes.

In each case, the code starts with a permutation representation of a set of generators of the group. This is used to determine the group structure using GAP, and the permutation representation of all elements. The results are used for each subgroup to verify transitivity. After that, a transitive subgroup is chosen (manually), and labels (q_i) around assigned around one vertex are transported to all vertices, and clashes are detected. In the end, positions of all labels and clashing labels are displayed.
