# gap file
#
Print("\n\nDetermining subgroups of the symmetry group of the cube.\nThe group is generated by the following generators:\n\tdouble cycle (1,2,3,4)(5,6,7,8) corresponding to a 2pi/4 rotation around an axis connecting centre points of faces 1,2,3,4 and 5,6,7,8\n\tdouble cycle (2,6,7,3)(1,5,8,4) corresponding to a 2pi/4 rotation around an axis connecting centre points of faces 2,6,7,3 and 1,5,8,4.\n");
#
CubeSymm := Group([(1,2,3,4)(5,6,7,8),(2,6,7,3)(1,5,8,4)]);
Print("\n\nSymmetry group of the cube: CubeSymm is now: ", CubeSymm, "\n");
Print("\n\nThe stucture of the group is: ", StructureDescription(CubeSymm), ".\n\n");
#
numpts := 8;
#
ord := Order(CubeSymm);
Print("\n\nOrder of the symmetry group: ", ord, "\n");
#
SGCubeSymm := AllSubgroups(CubeSymm);
Print("\n\nAll subgroups of the symmetry group of the cube CubeSymm are: ", SGCubeSymm,".\n");
#
transitiveSG:=[];
#
nsg := Length(SGCubeSymm);
Print("\n\nNumber of subgroups: ", nsg, ".\n");
#
Print("\n\nLooping over subgroups:\n");
for i in [1 .. nsg] do
  Print("\nSubgroup no. ", i, ": ", SGCubeSymm[i], ".\n");
  Print("Elements: ", Elements(SGCubeSymm[i]), ".\n");
  Print("Order of the subgroup: ", Order(SGCubeSymm[i]), ".\n");
  Print("Normal subgroup: ", IsNormal(CubeSymm, SGCubeSymm[i]), ".\n");
  orb1 := Orbit(SGCubeSymm[i], 1, OnPoints);
  Print("Orbit of point 1: ", orb1, "\n");
  if SortedList(orb1) = [1 .. numpts] then
    Print("Subgroup ", i," is transitive.\n");
    Add(transitiveSG, i);
  else
    Print("Subgroup ", i, " is not transitive.\n");
  fi;
  Print("Structure of subgroup ", i, ": ", StructureDescription(SGCubeSymm[i]), ".\n");
  if SGCubeSymm[i] = CubeSymm then Print("This is the full symmetry group.\n"); fi;
  Print("\n\n");
od;
#
Print("\n\nAre the D8s conjugate?\n");
IsConjugate(CubeSymm, SGCubeSymm[26], SGCubeSymm[27]);
IsConjugate(CubeSymm, SGCubeSymm[26], SGCubeSymm[28]);
#
Print("\nList of transitive subgroups: ", transitiveSG, ".\n\n\n");
#
# Labeling finder - we choose vertex 1, and list the angles around it, these will be the labels
Print("\nProceeding to labeling.\n\n");
initialLabels := [[2,1,4],[5,1,4],[2,1,5]];
labels := [];
#labelingGroup := SGCubeSymm[27];
labelingGroup := CubeSymm;
nElem := Length(Elements(labelingGroup));
nLabels := Length(initialLabels);
Print("Number of group elements: ", nElem, ", number of labels: ", nLabels, ".\n");
for i in [1 .. nLabels] do
  Add(labels, []);
od;
groupElements := Elements(labelingGroup);
#Print("Second element: ", groupElements[2], "\n");
#Print("First label: ", initialLabels[1], "\n");
#Print("First point: ", initialLabels[1][1], "\n");
#
for i in [1 .. nElem] do
  element := groupElements[i];
#  Print("Applying element ", i,": ", element, ".\n");
  for j in [1.. nLabels] do
     initialLabel := initialLabels[j];
     neighbours := SortedList([OnPoints(initialLabel[1], element),OnPoints(initialLabel[3], element)]);
     label := [neighbours[1], OnPoints(initialLabel[2], element), neighbours[2]];
     Print("Initial label: ", initialLabel, ", new label: ", label, ".\n");
     Add(labels[j], label);
  od;
od;
#
clashingLabels := [];
for i in [1 .. nLabels] do
  for j in [1 .. nLabels] do
    for k in [1 .. nElem] do
      for l in [1 .. nElem] do
        if labels[i][k] = labels[j][l] and i <> j then
          Print("Labels ", i, " and ", j , " must agree: they clash for transformations ", k , " and ", l, " at ", labels[i][k], ".\n");
          Add(clashingLabels, SortedList([i, j]));
#          Print("Clashing labels: ", clashingLabels, ", ", SortedList([i, j]), "\n");
        fi;
      od;
    od;
  od;
od;
clashingLabels := Unique(SortedList(clashingLabels));
Print("\n\n\nClashing labels: ", clashingLabels, ".\n");
for i in [1 .. nLabels] do
  Print("\nLabel ", i, " is at ", labels[i], ".\n");
od;
#
Print("\nDone.\n");
