# gap file
#
Print("\n\nDetermining subgroups of the symmetry group of the cuboctahedron.\nThe group is generated by the following generators:\n\t2pi/4 rotation around an axis connecting centre points of faces 1,2,3,4 and 9,10,1,12\n\t2pi/4 rotation around an axis connecting centre points of faces 1,6,10,5 and 3,7,12,8.\n");
#
g1 := (1,2,3,4)(5,6,7,8)(9,10,11,12);
g2 := (1,6,10,5)(3,7,12,8)(2,11,9,4);
CuboctaSymm := Group([g1, g2]);
Print("\n\nSymmetry group of the cuboctahedron: CuboctaSymm is now: ", CuboctaSymm, "\n");
Print("\n\nThe stucture of the group is: ", StructureDescription(CuboctaSymm), ".\n\n");
#
numpts := 12;
#
ord := Order(CuboctaSymm);
Print("\n\nOrder of the symmetry group: ", ord, "\n");
#
SGCuboctaSymm := AllSubgroups(CuboctaSymm);
Print("\n\nAll subgroups of the symmetry group of the cuboctahedron CuboctaSymm are: ", SGCuboctaSymm,".\n");
#
transitiveSG:=[];
#
nsg := Length(SGCuboctaSymm);
Print("\n\nNumber of subgroups: ", nsg, ".\n");
#
Print("\n\nLooping over subgroups:\n");
for i in [1 .. nsg] do
  Print("\nSubgroup no. ", i, ": ", SGCuboctaSymm[i], ".\n");
  Print("Elements: ", Elements(SGCuboctaSymm[i]), ".\n");
  Print("Order of the subgroup: ", Order(SGCuboctaSymm[i]), ".\n");
  Print("Normal subgroup: ", IsNormal(CuboctaSymm, SGCuboctaSymm[i]), ".\n");
  orb1 := Orbit(SGCuboctaSymm[i], 1, OnPoints);
  Print("Orbit of point 1: ", orb1, "\n");
  if SortedList(orb1) = [1 .. numpts] then
    Print("Subgroup ", i," is transitive.\n");
    Add(transitiveSG, i);
  else
    Print("Subgroup ", i, " is not transitive.\n");
  fi;
  Print("Structure of subgroup ", i, ": ", StructureDescription(SGCuboctaSymm[i]), ".\n");
  if SGCuboctaSymm[i] = CuboctaSymm then Print("This is the full symmetry group.\n"); fi;
  Print("\n\n");
od;
#
Print("\nIs the transitive subgroup 29 (A4) generated by pi rotations around face centres?\n");
gs1 := (1,12)(2,11)(3,10)(4,9)(5,8)(6,7);
gs2 := (1,3)(2,4)(5,7)(6,8)(9,11)(10,12);
gs3 := g2^2;
sg := Group([gs1, gs2, gs3]);
sg = SGCuboctaSymm[29];
Print("\nWhat subgroup is this then?\n");
StructureDescription(sg);
Print("\nWhat about groups generated by rotations around the cube main diagonals?\n");
gs1 := (1,7,9)(2,12,5)(3,8,4)(6,11,10);
gs2 := (1,4,5)(2,8,10)(3,9,6)(7,12,11);
gs3 := (1,6,2)(3,5,11)(4,10,7)(8,9,12);
gs4 := (1,11,8)(2,7,3)(4,6,12)(5,10,9);
#gs1 := (2,7,3)(5,10,9)(6,12,4)(1,11,8);
#gs2 := (1,6,2)(8,9,12)(5,10,3)(4,11,7);
#gs3 := (3,8,4)(6,11,10)(7,9,1)(2,12,5);
#gs4 := (1,7,9)(2,12,5)(3,8,4)(6,11,10);
sg := Group([gs1, gs2, gs3, gs4]);
Print("\nWhat subgroup is this? ", StructureDescription(sg), "\n");
Print("\nIs this the subgroup?\n");
sg = SGCuboctaSymm[29];
#
Print("\nList of transitive subgroups: ", transitiveSG, ".\n");
#
# Labeling finder - we choose vertex 1, and list the angles around it, these will be the labels
Print("\nProceeding to labeling.\n\n");
initialLabels := [[2,1,4],[4,1,5],[5,1,6],[6,1,2]];
labels := [];
labelingGroup := CuboctaSymm;
#labelingGroup := SGCuboctaSymm[29];
nElem := Length(Elements(labelingGroup));
nLabels := Length(initialLabels);
Print("Number of group elements: ", nElem, ", number of labels: ", nLabels, ".\n");
for i in [1 .. nLabels] do
  Add(labels, []);
od;
groupElements := Elements(labelingGroup);
#Print("Second element: ", groupElements[2], "\n");
#Print("First label: ", initialLabels[1], "\n");
#Print("First point: ", initialLabels[1][1], "\n");
#
for i in [1 .. nElem] do
  element := groupElements[i];
#  Print("Applying element ", i,": ", element, ".\n");
  for j in [1.. nLabels] do
     initialLabel := initialLabels[j];
     neighbours := SortedList([OnPoints(initialLabel[1], element),OnPoints(initialLabel[3], element)]);
     label := [neighbours[1], OnPoints(initialLabel[2], element), neighbours[2]];
     Print("Initial label: ", initialLabel, ", new label: ", label, ".\n");
     Add(labels[j], label);
  od;
od;
#
clashingLabels := [];
for i in [1 .. nLabels] do
  for j in [1 .. nLabels] do
    for k in [1 .. nElem] do
      for l in [1 .. nElem] do
        if labels[i][k] = labels[j][l] and i <> j then
          Print("Labels ", i, " and ", j , " must agree: they clash for transformations ", k , " and ", l, " at ", labels[i][k], ".\n");
          Add(clashingLabels, SortedList([i, j]));
#          Print("Clashing labels: ", clashingLabels, ", ", SortedList([i, j]), "\n");
        fi;
      od;
    od;
  od;
od;
clashingLabels := Unique(SortedList(clashingLabels));
Print("\n\n\nClashing labels: ", clashingLabels, ".\n");
for i in [1 .. nLabels] do
  Print("\nLabel ", i, " is at ", labels[i], ".\n");
od;
#
Print("\nDone.\n");
