# gap file
#
Print("\n\nDetermining subgroups of the symmetry group of the icosidodecahedron.\nThe group is generated by the following generators:\n\t2pi/5 rotation around an axis connecting faces 1,2,3,4,5 and 26,27,28,29,30 and\n\t2pi/5 rotation connecting vertices 4,9,14,19,10 and 12,22,27,21,16.\n");
#
g1 := (1,2,3,4,5)(6,7,8,9,10)(11,12,13,14,15)(16,17,18,19,20)(21,22,23,24,25)(26,27,28,29,30);
# always look for neighbours, if more: start with, e.g., left
g2 := (4,9,14,19,10) (3,18,24,15,5) (8,23,30,20,1)(2,13,29,25,6) (17,28,26,11,7)(22,27,21,16,12);
IcosidodecaSymm := Group([g1, g2]);
Print("\n\nSymmetry group of the icosidodecahedron: IcosidodecaSymm is now: ", IcosidodecaSymm, "\n");
Print("\n\nThe stucture of the group is: ", StructureDescription(IcosidodecaSymm), ".\n\n");
#
numpts := 30;
#
ord := Order(IcosidodecaSymm);
Print("\n\nOrder of the symmetry group: ", ord, "\n");
#
SGIcosidodecaSymm := AllSubgroups(IcosidodecaSymm);
Print("\n\nAll subgroups of the symmetry group of the icosidodecahedron IcosidodecaSymm are: ", SGIcosidodecaSymm,".\n");
#
nsg := Length(SGIcosidodecaSymm);
Print("\n\nNumber of subgroups: ", nsg, ".\n");
#
transitiveSG:=[];
#
Print("\n\nLooping over subgroups:\n");
for i in [1 .. nsg] do
  Print("\nSubgroup no. ", i, ": ", SGIcosidodecaSymm[i], ".\n");
  Print("Elements: ", Elements(SGIcosidodecaSymm[i]), ".\n");
  Print("Order of the subgroup: ", Order(SGIcosidodecaSymm[i]), ".\n");
  Print("Normal subgroup: ", IsNormal(IcosidodecaSymm, SGIcosidodecaSymm[i]), ".\n");
  orb1 := Orbit(SGIcosidodecaSymm[i], 1, OnPoints);
  Print("Orbit of point 1: ", orb1, "\n");
  if SortedList(orb1) = [1 .. numpts] then
    Print("Subgroup ", i," is transitive.\n");
    Add(transitiveSG, i);
  else
    Print("Subgroup ", i, " is not transitive.\n");
  fi;
  Print("Structure of subgroup ", i, ": ", StructureDescription(SGIcosidodecaSymm[i]), ".\n");
  if SGIcosidodecaSymm[i] = IcosidodecaSymm then Print("This is the full symmetry group.\n"); fi;
  Print("\n\n");
od;
#
#
Print("\nList of transitive subgroups: ", transitiveSG, ".\n\n\n");
#
# Labeling finder - we choose vertex 1, and list the angles around it, these will be the labels
Print("\nProceeding to labeling.\n\n");
initialLabels := [[7,1,2],[2,1,5],[5,1,6],[6,1,7]];
labels := [];
labelingGroup := IcosidodecaSymm;
nElem := Length(Elements(labelingGroup));
nLabels := Length(initialLabels);
Print("Number of group elements: ", nElem, ", number of labels: ", nLabels, ".\n");
for i in [1 .. nLabels] do
  Add(labels, []);
od;
groupElements := Elements(labelingGroup);
#Print("Second element: ", groupElements[2], "\n");
#Print("First label: ", initialLabels[1], "\n");
#Print("First point: ", initialLabels[1][1], "\n");
#
for i in [1 .. nElem] do
  element := groupElements[i];
#  Print("Applying element ", i,": ", element, ".\n");
  for j in [1.. nLabels] do
     initialLabel := initialLabels[j];
     neighbours := SortedList([OnPoints(initialLabel[1], element),OnPoints(initialLabel[3], element)]);
     label := [neighbours[1], OnPoints(initialLabel[2], element), neighbours[2]];
     Print("Initial label: ", initialLabel, ", new label: ", label, ".\n");
     Add(labels[j], label);
  od;
od;
#
clashingLabels := [];
for i in [1 .. nLabels] do
  for j in [1 .. nLabels] do
    for k in [1 .. nElem] do
      for l in [1 .. nElem] do
        if labels[i][k] = labels[j][l] and i <> j then
          Print("Labels ", i, " and ", j , " must agree: they clash for transformations ", k , " and ", l, " at ", labels[i][k], ".\n");
          Add(clashingLabels, SortedList([i, j]));
#          Print("Clashing labels: ", clashingLabels, ", ", SortedList([i, j]), "\n");
        fi;
      od;
    od;
  od;
od;
clashingLabels := Unique(SortedList(clashingLabels));
Print("\n\n\nClashing labels: ", clashingLabels, ".\n");
for i in [1 .. nLabels] do
  Print("\nLabel ", i, " is at ", labels[i], ".\n");
od;
#
Print("\nDone.\n");
