# gap file
#
Print("\n\nDetermining subgroups of the symmetry group of the octahedron.\nThe group is generated by the following generators:\n\tcycle (2,3,4,5) corresponding to a pi/2 rotation around an axis connecting vertices 1,6\n\tcycle (1,3,6,5) corresponding to a pi/2 rotation around an axis connecting vertices 2,4.\n");
#
OctaSymm := Group([(2,3,4,5), (1,3,6,5)]);
Print("\n\nSymmetry group of the octahedron: OctaSymm is now: ", OctaSymm, "\n");
Print("\n\nThe stucture of the group is: ", StructureDescription(OctaSymm), ".\n\n");
#
numpts := 6;
#
ord := Order(OctaSymm);
Print("\n\nOrder of the symmetry group: ", ord, "\n");
#
SGOctaSymm := AllSubgroups(OctaSymm);
Print("\n\nAll subgroups of the symmetry group of the octahedron OctaSymm are: ", SGOctaSymm,".\n");
#
transitiveSG:=[];
#
nsg := Length(SGOctaSymm);
Print("\n\nNumber of subgroups: ", nsg, ".\n");
#
Print("\n\nLooping over subgroups:\n");
for i in [1 .. nsg] do
  Print("\nSubgroup no. ", i, ": ", SGOctaSymm[i], ".\n");
  Print("Elements: ", Elements(SGOctaSymm[i]), ".\n");
  Print("Order of the subgroup: ", Order(SGOctaSymm[i]), ".\n");
  Print("Normal subgroup: ", IsNormal(OctaSymm, SGOctaSymm[i]), ".\n");
  orb1 := Orbit(SGOctaSymm[i], 1, OnPoints);
  Print("Orbit of point 1: ", orb1, "\n");
  if SortedList(orb1) = [1 .. numpts] then
    Print("Subgroup ", i," is transitive.\n");
    Add(transitiveSG, i);
  else
    Print("Subgroup ", i, " is not transitive.\n");
  fi;
  Print("Structure of subgroup ", i, ": ", StructureDescription(SGOctaSymm[i]), ".\n");
  if SGOctaSymm[i] = OctaSymm then Print("This is the full symmetry group.\n"); fi;
  Print("\n\n");
od;
#
Print("\n\nWhat is the A4 group? Is it generated by pi rotations around axes connecting opposite vertices?\n");
QG := Group([(1,6)(3,5), (2,4)(3,5), (1,6)(2,4)]);
if QG = SGOctaSymm[29] then Print("\n\nYes.\n"); else Print("\n\nNo.\n"); fi;
Print("What is this group then? Structure: ", StructureDescription(QG), ".\n");
Print("\n\nIs it then generated by 2pi/3 rotations around axes connecting face centres 1,4,5 and , and 2,3,6 and a pi rotation connecting edge centres 1,6 and 3,5?\n");
QG := Group([(1,6)(3,5), (1,4,5)(2,3,6)]);
if QG = SGOctaSymm[29] then Print("\n\nYes.\n"); else Print("\n\nNo.\n"); fi;
Print("What is this group then? Structure: ", StructureDescription(QG), ".\n");
#
Print("\n\nAre the S3 subgroups conjugate?\nConjugacy classes:\n");
CGS3 := ConjugateSubgroups(OctaSymm, SGOctaSymm[22]);
Print("Number of conjugate subgroups: ", Length(CGS3), ".\n\tConclusion: the 4 S3's are conjugate.\nDirect verification:");
IsConjugate(OctaSymm, SGOctaSymm[22], SGOctaSymm[23]);
IsConjugate(OctaSymm, SGOctaSymm[22], SGOctaSymm[24]);
IsConjugate(OctaSymm, SGOctaSymm[22], SGOctaSymm[25]);
#
Print("\n\nAre the S3's contained in the A4? \n\t", IsSubgroup(SGOctaSymm[22], SGOctaSymm[29]), "\n\t", IsSubgroup(SGOctaSymm[23], SGOctaSymm[29]), "\n\t", IsSubgroup(SGOctaSymm[24], SGOctaSymm[29]), "\n\t", IsSubgroup(SGOctaSymm[25], SGOctaSymm[29]), ".\nNo, they are not.\n");
#
Print("\nList of transitive subgroups: ", transitiveSG, ".\n\n\n");
#
# Labeling finder - we choose vertex 1, and list the angles around it, these will be the labels
Print("\nProceeding to labeling.\n\n");
initialLabels := [[2,1,3],[3,1,4],[4,1,5],[2,1,5]];
labels := [];
labelingGroup := OctaSymm;
#labelingGroup := SGOctaSymm[29];
#labelingGroup := SGOctaSymm[24];
nElem := Length(Elements(labelingGroup));
nLabels := Length(initialLabels);
Print("Number of group elements: ", nElem, ", number of labels: ", nLabels, ".\n");
for i in [1 .. nLabels] do
  Add(labels, []);
od;
groupElements := Elements(labelingGroup);
#Print("Second element: ", groupElements[2], "\n");
#Print("First label: ", initialLabels[1], "\n");
#Print("First point: ", initialLabels[1][1], "\n");
#
for i in [1 .. nElem] do
  element := groupElements[i];
#  Print("Applying element ", i,": ", element, ".\n");
  for j in [1.. nLabels] do
     initialLabel := initialLabels[j];
     neighbours := SortedList([OnPoints(initialLabel[1], element),OnPoints(initialLabel[3], element)]);
     label := [neighbours[1], OnPoints(initialLabel[2], element), neighbours[2]];
     Print("Initial label: ", initialLabel, ", new label: ", label, ".\n");
     Add(labels[j], label);
  od;
od;
#
clashingLabels := [];
for i in [1 .. nLabels] do
  for j in [1 .. nLabels] do
    for k in [1 .. nElem] do
      for l in [1 .. nElem] do
        if labels[i][k] = labels[j][l] and i <> j then
          Print("Labels ", i, " and ", j , " must agree: they clash for transformations ", k , " and ", l, " at ", labels[i][k], ".\n");
          Add(clashingLabels, SortedList([i, j]));
#          Print("Clashing labels: ", clashingLabels, ", ", SortedList([i, j]), "\n");
        fi;
      od;
    od;
  od;
od;
clashingLabels := Unique(SortedList(clashingLabels));
Print("\n\n\nClashing labels: ", clashingLabels, ".\n");
for i in [1 .. nLabels] do
  Print("\nLabel ", i, " is at ", labels[i], ".\n");
od;
#
Print("\nDone.\n");
