# gap file
#
Print("\n\nDetermining subgroups of the symmetry group of the rhombicosidodecahedron.\nThe group is generated by the following generators:\n\t2pi/5 rotation around an axis connecting centres of faces 1,2,3,4,5 and 56,57,58,59,60 and\n\t2pi/5 rotation connecting centres of faces 9,19,29,25,15 and 32,37,47,52,42.\n");
#
g1 := (1,2,3,4,5)(6,7,8,9,10)(11,12,13,14,15)(16,17,18,19,20)(21,22,23,24,25)(26,27,28,29,30)(31,32,33,34,35)(36,37,38,39,40)(41,42,43,44,45)(46,47,48,49,50)(51,52,53,54,55)(56,57,58,59,60);
g2 := (9,19,29,24,15)(14,34,45,20,5)(4,23,39,35,10)(8,44,55,30,1)(3,28,49,40,11)(18,54,50,25,2)(13,38,59,41,6)(33,58,51,16,7)(22,48,60,31,12)(43,57,46,26,17)(27,53,56,36,21)(37,47,52,42,32);
RIDodecaSymm := Group([g1,g2]);
Print("\n\nSymmetry group of the dodecahedron: RIDodecaSymm is now: ", RIDodecaSymm, "\n");
Print("\n\nThe stucture of the group is: ", StructureDescription(RIDodecaSymm), ".\n\n");
#
numpts := 60;
#
ord := Order(RIDodecaSymm);
Print("\n\nOrder of the symmetry group: ", ord, "\n");
#
SGRIDodecaSymm := AllSubgroups(RIDodecaSymm);
Print("\n\nAll subgroups of the symmetry group of the dodecahedron RIDodecaSymm are: ", SGRIDodecaSymm,".\n");
#
nsg := Length(SGRIDodecaSymm);
Print("\n\nNumber of subgroups: ", nsg, ".\n");
#
transitiveSG:=[];
#
Print("\n\nLooping over subgroups:\n");
for i in [1 .. nsg] do
  Print("\nSubgroup no. ", i, ": ", SGRIDodecaSymm[i], ".\n");
  Print("Elements: ", Elements(SGRIDodecaSymm[i]), ".\n");
  Print("Order of the subgroup: ", Order(SGRIDodecaSymm[i]), ".\n");
  Print("Normal subgroup: ", IsNormal(RIDodecaSymm, SGRIDodecaSymm[i]), ".\n");
  orb1 := Orbit(SGRIDodecaSymm[i], 1, OnPoints);
  Print("Orbit of point 1: ", orb1, "\n");
  if SortedList(orb1) = [1 .. numpts] then
    Print("Subgroup ", i," is transitive.\n");
    Add(transitiveSG, i);
  else
    Print("Subgroup ", i, " is not transitive.\n");
  fi;
  Print("Structure of subgroup ", i, ": ", StructureDescription(SGRIDodecaSymm[i]), ".\n");
  if SGRIDodecaSymm[i] = RIDodecaSymm then Print("This is the full symmetry group.\n"); fi;
  Print("\n\n");
od;
#
#
Print("\nList of transitive subgroups: ", transitiveSG, ".\n");
#
# Labeling finder - we choose vertex 1, and list the angles around it, these will be the labels
Print("\nProceeding to labeling.\n\n");
initialLabels := [[6,1,2],[2,1,5],[5,1,11],[11,1,6]];
labels := [];
labelingGroup := RIDodecaSymm;
nElem := Length(Elements(labelingGroup));
nLabels := Length(initialLabels);
Print("Number of group elements: ", nElem, ", number of labels: ", nLabels, ".\n");
for i in [1 .. nLabels] do
  Add(labels, []);
od;
groupElements := Elements(labelingGroup);
#Print("Second element: ", groupElements[2], "\n");
#Print("First label: ", initialLabels[1], "\n");
#Print("First point: ", initialLabels[1][1], "\n");
#
for i in [1 .. nElem] do
  element := groupElements[i];
#  Print("Applying element ", i,": ", element, ".\n");
  for j in [1.. nLabels] do
     initialLabel := initialLabels[j];
     neighbours := SortedList([OnPoints(initialLabel[1], element),OnPoints(initialLabel[3], element)]);
     label := [neighbours[1], OnPoints(initialLabel[2], element), neighbours[2]];
     Print("Initial label: ", initialLabel, ", new label: ", label, ".\n");
     Add(labels[j], label);
  od;
od;
#
clashingLabels := [];
for i in [1 .. nLabels] do
  for j in [1 .. nLabels] do
    for k in [1 .. nElem] do
      for l in [1 .. nElem] do
        if labels[i][k] = labels[j][l] and i <> j then
          Print("Labels ", i, " and ", j , " must agree: they clash for transformations ", k , " and ", l, " at ", labels[i][k], ".\n");
          Add(clashingLabels, SortedList([i, j]));
#          Print("Clashing labels: ", clashingLabels, ", ", SortedList([i, j]), "\n");
        fi;
      od;
    od;
  od;
od;
clashingLabels := Unique(SortedList(clashingLabels));
Print("\n\n\nClashing labels: ", clashingLabels, ".\n");
for i in [1 .. nLabels] do
  Print("\nLabel ", i, " is at ", labels[i], ".\n");
od;
#
Print("\nDone.\n");
