# gap file
#
Print("\n\nDetermining subgroups of the symmetry group of the rhombicuboctahedron.\nThe group is generated by the following generators:\n\tsextuple cycle (1,2,3,4)(5,6,7,8)(9,10,11,12)(13,14,15,16)(17,18,19,20)(21,22,23,24) corresponding to a 2pi/4 rotation around an axis connecting centre points of faces 1,2,3,4 and 21,22,23,24\n\tsextuple cycle (6,19,15,10)(9,23,20,3)(2,14,24,7)(5,22,16,4)(1,18,21,11)(8,13,12,17) corresponding to a 2pi/4 rotation around an axis connecting centre points of faces 6,19,15,10 and 8,13,12,17.\n");
#
g1 := (1,2,3,4)(5,6,7,8)(9,10,11,12)(13,14,15,16)(17,18,19,20)(21,22,23,24);
g2 := (6,19,15,10)(9,23,20,3)(2,14,24,7)(5,22,16,4)(1,18,21,11)(8,12,13,17);
RhombicuboctaSymm := Group([g1, g2]);
Print("\n\nSymmetry group of the rhombicuboctahedron: RhombicuboctaSymm is now: ", RhombicuboctaSymm, "\n");
Print("\n\nThe stucture of the group is: ", StructureDescription(RhombicuboctaSymm), ".\n\n");
#
numpts := 24;
#
ord := Order(RhombicuboctaSymm);
Print("\n\nOrder of the symmetry group: ", ord, "\n");
#
SGRhombicuboctaSymm := AllSubgroups(RhombicuboctaSymm);
Print("\n\nAll subgroups of the symmetry group of the rhombicuboctahedron RhombicuboctaSymm are: ", SGRhombicuboctaSymm,".\n");
#
transitiveSG:=[];
#
nsg := Length(SGRhombicuboctaSymm);
Print("\n\nNumber of subgroups: ", nsg, ".\n");
#
Print("\n\nLooping over subgroups:\n");
for i in [1 .. nsg] do
  Print("\nSubgroup no. ", i, ": ", SGRhombicuboctaSymm[i], ".\n");
  Print("Elements: ", Elements(SGRhombicuboctaSymm[i]), ".\n");
  Print("Order of the subgroup: ", Order(SGRhombicuboctaSymm[i]), ".\n");
  Print("Normal subgroup: ", IsNormal(RhombicuboctaSymm, SGRhombicuboctaSymm[i]), ".\n");
  orb1 := Orbit(SGRhombicuboctaSymm[i], 1, OnPoints);
  Print("Orbit of point 1: ", orb1, "\n");
  if SortedList(orb1) = [1 .. numpts] then
    Print("Subgroup ", i," is transitive.\n");
    Add(transitiveSG, i);
  else
    Print("Subgroup ", i, " is not transitive.\n");
  fi;
  Print("Structure of subgroup ", i, ": ", StructureDescription(SGRhombicuboctaSymm[i]), ".\n");
  if SGRhombicuboctaSymm[i] = RhombicuboctaSymm then Print("This is the full symmetry group.\n"); fi;
  Print("\n\n");
od;
#
Print("\n\nAre the D8s conjugate?\n");
IsConjugate(RhombicuboctaSymm, SGRhombicuboctaSymm[26], SGRhombicuboctaSymm[27]);
IsConjugate(RhombicuboctaSymm, SGRhombicuboctaSymm[26], SGRhombicuboctaSymm[28]);
#
Print("\nList of transitive subgroups: ", transitiveSG, ".\n");
#
# Labeling finder - we choose vertex 1, and list the angles around it, these will be the labels
Print("\nProceeding to labeling.\n\n");
initialLabels := [[2,1,4],[4,1,12],[12,1,5],[5,1,2]];
labels := [];
labelingGroup := RhombicuboctaSymm;
nElem := Length(Elements(labelingGroup));
nLabels := Length(initialLabels);
Print("Number of group elements: ", nElem, ", number of labels: ", nLabels, ".\n");
for i in [1 .. nLabels] do
  Add(labels, []);
od;
groupElements := Elements(labelingGroup);
#Print("Second element: ", groupElements[2], "\n");
#Print("First label: ", initialLabels[1], "\n");
#Print("First point: ", initialLabels[1][1], "\n");
#
for i in [1 .. nElem] do
  element := groupElements[i];
#  Print("Applying element ", i,": ", element, ".\n");
  for j in [1.. nLabels] do
     initialLabel := initialLabels[j];
     neighbours := SortedList([OnPoints(initialLabel[1], element),OnPoints(initialLabel[3], element)]);
     label := [neighbours[1], OnPoints(initialLabel[2], element), neighbours[2]];
     Print("Initial label: ", initialLabel, ", new label: ", label, ".\n");
     Add(labels[j], label);
  od;
od;
#
clashingLabels := [];
for i in [1 .. nLabels] do
  for j in [1 .. nLabels] do
    for k in [1 .. nElem] do
      for l in [1 .. nElem] do
        if labels[i][k] = labels[j][l] and i <> j then
          Print("Labels ", i, " and ", j , " must agree: they clash for transformations ", k , " and ", l, " at ", labels[i][k], ".\n");
          Add(clashingLabels, SortedList([i, j]));
#          Print("Clashing labels: ", clashingLabels, ", ", SortedList([i, j]), "\n");
        fi;
      od;
    od;
  od;
od;
clashingLabels := Unique(SortedList(clashingLabels));
Print("\n\n\nClashing labels: ", clashingLabels, ".\n");
for i in [1 .. nLabels] do
  Print("\nLabel ", i, " is at ", labels[i], ".\n");
od;
#
Print("\nDone.\n");
