# gap file
#
Print("\n\nDetermining subgroups of the symmetry group of the tetrahedron.\nThe group is generated by the following generators:\n\tcycle (1,2,3) corresponding to a 2pi/3 rotation around an axis connecting vertex 4 with cm of face 1,2,3\n\tdouble transposition (1,2)(3,4) corresponding to a pi rotation around an axis connecting half-edge points of edges 1,2 and 3,4.\n");
## set of generators:
# rot by pi/3 around axis connecting 4 and cm of 123 is (2,3,1)
# rot by pi around axis connecting cm of 12 and 34 is (2,1)(4,3)
#
TetraSymm := Group([(1,2,3), (1,2)(3,4)]);
Print("\n\nSymmetry group of the tetrahedron: TetraSymm is now: ", TetraSymm, "\n");
Print("\n\nThe stucture of the group is: ", StructureDescription(TetraSymm), ".\n\n");
#
numpts := 4;
#
ord := Order(TetraSymm);
Print("\n\nOrder of the symmetry group: ", ord, "\n");
#
SGTetraSymm := AllSubgroups(TetraSymm);
Print("\n\nAll subgroups of the symmetry group of the tetrahedron TetraSymm are: ", SGTetraSymm,".\n");
#
nsg := Length(SGTetraSymm);
Print("\n\nNumber of subgroups: ", nsg, ".\n");
#
transitiveSG:=[];
#
Print("\n\nLooping over subgroups:\n");
for i in [1 .. nsg] do
  Print("\nSubgroup no. ", i, ": ", SGTetraSymm[i], ".\n");
  Print("Order of the subgroup: ", Order(SGTetraSymm[i]), ".\n");
  Print("Normal subgroup: ", IsNormal(TetraSymm, SGTetraSymm[i]), ".\n");
  orb1 := Orbit(SGTetraSymm[i], 1, OnPoints);
  Print("Orbit of point 1: ", orb1, "\n");
  if SortedList(orb1) = [1 .. numpts] then
    Print("Subgroup ", i," is transitive.\n");
    Print("Elements: ", Elements(SGTetraSymm[i]), ".\n");
    Add(transitiveSG, i);
  else
    Print("Subgroup ", i, " is not transitive.\n");
  fi;
  Print("Structure of subgroup ", i, ": ", StructureDescription(SGTetraSymm[i]), ".\n");
  if SGTetraSymm[i] = TetraSymm then Print("This is the full symmetry group.\n"); fi;
  Print("\n\n");
od;
#
#
Print("\nList of transitive subgroups: ", transitiveSG, ".\n");
#
Print("\nProceeding to labeling.\n\n");
initialLabels := [[2,1,4],[4,1,3],[3,1,2]];
labels := [];
nElem := Length(Elements(SGTetraSymm[9]));
groupElements := Elements(SGTetraSymm[9]);
#nElem := Length(Elements(SGTetraSymm[10]));
#groupElements := Elements(SGTetraSymm[10]);
nLabels := Length(initialLabels);
Print("Number of group elements: ", nElem, ", number of labels: ", nLabels, ".\n");
for i in [1 .. nLabels] do
  Add(labels, []);
od;
#Print("Second element: ", groupElements[2], "\n");
#Print("First label: ", initialLabels[1], "\n");
#Print("First point: ", initialLabels[1][1], "\n");
#
for i in [1 .. nElem] do
  element := groupElements[i];
#  Print("Applying element ", i,": ", element, ".\n");
  for j in [1.. nLabels] do
     initialLabel := initialLabels[j];
     neighbours := SortedList([OnPoints(initialLabel[1], element),OnPoints(initialLabel[3], element)]);
     label := [neighbours[1], OnPoints(initialLabel[2], element), neighbours[2]];
     Print("Initial label: ", initialLabel, ", new label: ", label, ".\n");
     Add(labels[j], label);
  od;
od;
#
clashingLabels := [];
for i in [1 .. nLabels] do
  for j in [1 .. nLabels] do
    for k in [1 .. nElem] do
      for l in [1 .. nElem] do
        if labels[i][k] = labels[j][l] and i <> j then
          Print("Labels ", i, " and ", j , " must agree: they clash for transformations ", k , " and ", l, " at ", labels[i][k], ".\n");
          Add(clashingLabels, SortedList([i, j]));
#          Print("Clashing labels: ", clashingLabels, ", ", SortedList([i, j]), "\n");
        fi;
      od;
    od;
  od;
od;
clashingLabels := Unique(SortedList(clashingLabels));
Print("\n\n\nClashing labels: ", clashingLabels, ".\n");
for i in [1 .. nLabels] do
  Print("\nLabel ", i, " is at ", labels[i], ".\n");
od;
#
Print("\nDone.\n");
