# gap file
#
Print("\n\nDetermining subgroups of the symmetry group of the truncated cuboctahedron.\nThe group is generated by the following generators:\n\ta 2pi/4 rotation around an axis connecting centre points of faces 1,6,2,7,3,8,4,5 and 41,45,42,46,43,47,48\n\ta 2pi/4 rotation around an axis connecting centre points of faces 12,20,28,36,40,29,21,13 and 10,15,23,31,38,34,26,18.\n");
#
g1 := (1,2,3,4)(5,6,7,8)(9,10,11,12)(13,14,15,16)(17,18,19,20)(21,22,23,24)(25,26,27,28)(29,30,31,32)(33,34,35,36)(37,38,39,40)(41,42,43,44)(45,46,47,48);
g2 := (12,28,40,21)(13,20,36,29)(4,32,48,17)(5,24,44,25)(8,39,41,9)(1,16,47,33)(3,35,45,14)(6,11,43,37)(7,27,42,22)(2,19,46,30)(15,31,34,18)(10,23,38,26);
TruncCuboctaSymm := Group([g1, g2]);
Print("\n\nSymmetry group of the truncated cuboctahedron: TruncCuboctaSymm is now: ", TruncCuboctaSymm, "\n");
Print("\n\nThe stucture of the group is: ", StructureDescription(TruncCuboctaSymm), ".\n\n");
#
numpts := 48;
#
Print("\nOrbit of point 1:\n");
orb1fg := SortedList(Orbit(TruncCuboctaSymm, 1, OnPoints));
Print("\nIs the group action transitive? ", orb1fg = [1 .. numpts], ".\n");
#
ord := Order(TruncCuboctaSymm);
Print("\n\nOrder of the symmetry group: ", ord, "\n");
#
SGTruncCuboctaSymm := AllSubgroups(TruncCuboctaSymm);
Print("\n\nAll subgroups of the symmetry group of the truncated cuboctahedron TruncCuboctaSymm are: ", SGTruncCuboctaSymm,".\n");
#
transitiveSG := [];
orb1fSG := [];
#
nsg := Length(SGTruncCuboctaSymm);
Print("\n\nNumber of subgroups: ", nsg, ".\n");
#
Print("\n\nLooping over subgroups:\n");
for i in [1 .. nsg] do
  Print("\nSubgroup no. ", i, ": ", SGTruncCuboctaSymm[i], ".\n");
  Print("Elements: ", Elements(SGTruncCuboctaSymm[i]), ".\n");
  Print("Order of the subgroup: ", Order(SGTruncCuboctaSymm[i]), ".\n");
  Print("Normal subgroup: ", IsNormal(TruncCuboctaSymm, SGTruncCuboctaSymm[i]), ".\n");
  orb1 := Orbit(SGTruncCuboctaSymm[i], 1, OnPoints);
  Print("Orbit of point 1: ", orb1, "\n");
  if SortedList(orb1) = [1 .. numpts] then
    Print("Subgroup ", i," is transitive.\n");
    Add(transitiveSG, i);
  else
    Print("Subgroup ", i, " is not transitive.\n");
  fi;
  if SortedList(orb1) = orb1fg then
    Print("For subgroup ", i," the orbit of point 1 is the same as for the full group.\n");
    Add(orb1fSG, i);
  else
    Print("The orbit of point 1 for subgroup ", i, " is smaller than for the full group.\n");
  fi;
  Print("Structure of subgroup ", i, ": ", StructureDescription(SGTruncCuboctaSymm[i]), ".\n");
  if SGTruncCuboctaSymm[i] = TruncCuboctaSymm then Print("This is the full symmetry group.\n"); fi;
  Print("\n\n");
od;
#
Print("\n\nAre the D8s conjugate?\n");
IsConjugate(TruncCuboctaSymm, SGTruncCuboctaSymm[26], SGTruncCuboctaSymm[27]);
IsConjugate(TruncCuboctaSymm, SGTruncCuboctaSymm[26], SGTruncCuboctaSymm[28]);
#
Print("\nList of transitive subgroups: ", transitiveSG, ".\n");
Print("\nOrbit of point 1 :", SortedList(Orbit(TruncCuboctaSymm, 1, OnPoints)), ".\n");
Print("\nOrbit of point 2 :", SortedList(Orbit(TruncCuboctaSymm, 5, OnPoints)), ".\n");
Print("\nList of subgroups where orbit of point 1 is the same as for the full group: ", orb1fSG);
#
Print("\nDone.\n");
