# gap file
#
Print("\n\nDetermining subgroups of the symmetry group of the truncated dodecahedron.\nThe group is generated by the following generators:\n\t2pi/5 rotation around an axis connecting centres of faces 1,6,2,7,3,8,4,9,5,10 and 51,57,52,58,53,59,54,60,55,56 and\n\t2pi/5 rotation connecting centres of faces 4,14,20,26,32,38,21,16,15,9 and 23,29,35,42,48,54,59,47,41,40.\n");
#
g1 := (1,2,3,4,5)(6,7,8,9,10)(11,12,13,14,15)(16,17,18,19,20)(21,22,23,24,25)(26,27,28,29,30)(31,32,33,34,35)(36,37,38,39,40)(41,42,43,44,45)(46,47,48,49,50)(51,52,53,54,55)(56,57,58,59,60);
g2 := (4,20,32,21,15)(9,14,26,38,16)(5,8,25,44,27)(10,3,37,50,33)(11,7,31,51,45)(1,13,43,57,39)(17,2,30,56,46)(6,19,49,52,22)(28,12,24,55,58)(34,18,36,60,53)(41,23,35,48,59)(40,29,42,54,47);
DodecaSymm := Group([g1,g2]);
Print("\n\nSymmetry group of the dodecahedron: DodecaSymm is now: ", DodecaSymm, "\n");
Print("\n\nThe stucture of the group is: ", StructureDescription(DodecaSymm), ".\n\n");
#
numpts := 60;
#
ord := Order(DodecaSymm);
Print("\n\nOrder of the symmetry group: ", ord, "\n");
#
SGDodecaSymm := AllSubgroups(DodecaSymm);
Print("\n\nAll subgroups of the symmetry group of the dodecahedron DodecaSymm are: ", SGDodecaSymm,".\n");
#
nsg := Length(SGDodecaSymm);
Print("\n\nNumber of subgroups: ", nsg, ".\n");
#
transitiveSG:=[];
#
Print("\n\nLooping over subgroups:\n");
for i in [1 .. nsg] do
  Print("\nSubgroup no. ", i, ": ", SGDodecaSymm[i], ".\n");
  Print("Elements: ", Elements(SGDodecaSymm[i]), ".\n");
  Print("Order of the subgroup: ", Order(SGDodecaSymm[i]), ".\n");
  Print("Normal subgroup: ", IsNormal(DodecaSymm, SGDodecaSymm[i]), ".\n");
  orb1 := Orbit(SGDodecaSymm[i], 1, OnPoints);
  Print("Orbit of point 1: ", orb1, "\n");
  if SortedList(orb1) = [1 .. numpts] then
    Print("Subgroup ", i," is transitive.\n");
    Add(transitiveSG, i);
  else
    Print("Subgroup ", i, " is not transitive.\n");
  fi;
  Print("Structure of subgroup ", i, ": ", StructureDescription(SGDodecaSymm[i]), ".\n");
  if SGDodecaSymm[i] = DodecaSymm then Print("This is the full symmetry group.\n"); fi;
  Print("\n\n");
od;
#
#
Print("\nList of transitive subgroups: ", transitiveSG, ".\n");
#
# Labeling finder - we choose vertex 1, and list the angles around it, these will be the labels
Print("\nProceeding to labeling.\n\n");
initialLabels := [[6,1,10],[10,1,11],[11,1,6]];
labels := [];
labelingGroup := DodecaSymm;
nElem := Length(Elements(labelingGroup));
nLabels := Length(initialLabels);
Print("Number of group elements: ", nElem, ", number of labels: ", nLabels, ".\n");
for i in [1 .. nLabels] do
  Add(labels, []);
od;
groupElements := Elements(labelingGroup);
#Print("Second element: ", groupElements[2], "\n");
#Print("First label: ", initialLabels[1], "\n");
#Print("First point: ", initialLabels[1][1], "\n");
#
for i in [1 .. nElem] do
  element := groupElements[i];
#  Print("Applying element ", i,": ", element, ".\n");
  for j in [1.. nLabels] do
     initialLabel := initialLabels[j];
     neighbours := SortedList([OnPoints(initialLabel[1], element),OnPoints(initialLabel[3], element)]);
     label := [neighbours[1], OnPoints(initialLabel[2], element), neighbours[2]];
     Print("Initial label: ", initialLabel, ", new label: ", label, ".\n");
     Add(labels[j], label);
  od;
od;
#
clashingLabels := [];
for i in [1 .. nLabels] do
  for j in [1 .. nLabels] do
    for k in [1 .. nElem] do
      for l in [1 .. nElem] do
        if labels[i][k] = labels[j][l] and i <> j then
          Print("Labels ", i, " and ", j , " must agree: they clash for transformations ", k , " and ", l, " at ", labels[i][k], ".\n");
          Add(clashingLabels, SortedList([i, j]));
#          Print("Clashing labels: ", clashingLabels, ", ", SortedList([i, j]), "\n");
        fi;
      od;
    od;
  od;
od;
clashingLabels := Unique(SortedList(clashingLabels));
Print("\n\n\nClashing labels: ", clashingLabels, ".\n");
for i in [1 .. nLabels] do
  Print("\nLabel ", i, " is at ", labels[i], ".\n");
od;
#
Print("\nDone.\n");
