# gap file
#
Print("\n\nDetermining subgroups of the symmetry group of the icosahedron.\nThe group is generated by the following generators:\n\t2pi/5 rotation around an axis connecting centres of faces 3,6,12,21,9 and 46, 52, 58, 55, 49 and\n\t2pi/5 rotation connecting centres of faces  and 9.\n");
#
# method: choose one of the two, then neighbours, 2nd neighbours, etc.
# verification: shall obtain the other of the two faces at the end, clockwise
g1 := (3,6,12,21,9) (4,2,17,33,15) (10,5,14,39,24)(1,8,26,36,18) (19,11,23,42,30)(7,20,29,45,27) (31,16,35,53,48)(13,32,47,51,37) (34,25,44,59,54)(22,38,50,57,40) (43,28,41,56,60) (46,52,58,55,49);
g2 := (14,23,29,26,17) (8,35,47,39,12) (2,32,50,42,21)(20,44,53,33,6) (5,38,56,45,9)(11,41,59,36,3) (1,25,58,51,15)(16,52,57,24,4) (7,28,55,48,18)(13,46,60,30,10) (19,22,49,54,27) (31,34,43,40,37);
IcosaSymm := Group([g1, g2]);
Print("\n\nSymmetry group of the icosahedron: IcosaSymm is now: ", IcosaSymm, "\n");
Print("\n\nThe stucture of the group is: ", StructureDescription(IcosaSymm), ".\n\n");
#
numpts := 60;
#
ord := Order(IcosaSymm);
Print("\n\nOrder of the symmetry group: ", ord, "\n");
#
SGIcosaSymm := AllSubgroups(IcosaSymm);
Print("\n\nAll subgroups of the symmetry group of the icosahedron IcosaSymm are: ", SGIcosaSymm,".\n");
#
nsg := Length(SGIcosaSymm);
Print("\n\nNumber of subgroups: ", nsg, ".\n");
#
transitiveSG:=[];
#
Print("\n\nLooping over subgroups:\n");
for i in [1 .. nsg] do
  Print("\nSubgroup no. ", i, ": ", SGIcosaSymm[i], ".\n");
  Print("Elements: ", Elements(SGIcosaSymm[i]), ".\n");
  Print("Order of the subgroup: ", Order(SGIcosaSymm[i]), ".\n");
  Print("Normal subgroup: ", IsNormal(IcosaSymm, SGIcosaSymm[i]), ".\n");
  orb1 := Orbit(SGIcosaSymm[i], 1, OnPoints);
  Print("Orbit of point 1: ", orb1, "\n");
  if SortedList(orb1) = [1 .. numpts] then
    Print("Subgroup ", i," is transitive.\n");
    Add(transitiveSG, i);
  else
    Print("Subgroup ", i, " is not transitive.\n");
  fi;
  Print("Structure of subgroup ", i, ": ", StructureDescription(SGIcosaSymm[i]), ".\n");
  if SGIcosaSymm[i] = IcosaSymm then Print("This is the full symmetry group.\n"); fi;
  Print("\n\n");
od;
#
#
Print("\nList of transitive subgroups: ", transitiveSG, ".\n");
#
Print("\nAre the A4 subgroups 54, 55, 56, 57, 58 conjugate?\n");
IsConjugate(IcosaSymm, SGIcosaSymm[54], SGIcosaSymm[55]);
IsConjugate(IcosaSymm, SGIcosaSymm[54], SGIcosaSymm[56]);
IsConjugate(IcosaSymm, SGIcosaSymm[54], SGIcosaSymm[57]);
IsConjugate(IcosaSymm, SGIcosaSymm[54], SGIcosaSymm[58]);
#
# Labeling finder - we choose vertex 1, and list the angles around it, these will be the labels
Print("\nProceeding to labeling.\n\n");
initialLabels := [[7,1,5],[5,1,4],[4,1,7]];
labels := [];
labelingGroup := IcosaSymm;
nElem := Length(Elements(labelingGroup));
nLabels := Length(initialLabels);
Print("Number of group elements: ", nElem, ", number of labels: ", nLabels, ".\n");
for i in [1 .. nLabels] do
  Add(labels, []);
od;
groupElements := Elements(labelingGroup);
#Print("Second element: ", groupElements[2], "\n");
#Print("First label: ", initialLabels[1], "\n");
#Print("First point: ", initialLabels[1][1], "\n");
#
for i in [1 .. nElem] do
  element := groupElements[i];
#  Print("Applying element ", i,": ", element, ".\n");
  for j in [1.. nLabels] do
     initialLabel := initialLabels[j];
     neighbours := SortedList([OnPoints(initialLabel[1], element),OnPoints(initialLabel[3], element)]);
     label := [neighbours[1], OnPoints(initialLabel[2], element), neighbours[2]];
     Print("Initial label: ", initialLabel, ", new label: ", label, ".\n");
     Add(labels[j], label);
  od;
od;
#
clashingLabels := [];
for i in [1 .. nLabels] do
  for j in [1 .. nLabels] do
    for k in [1 .. nElem] do
      for l in [1 .. nElem] do
        if labels[i][k] = labels[j][l] and i <> j then
          Print("Labels ", i, " and ", j , " must agree: they clash for transformations ", k , " and ", l, " at ", labels[i][k], ".\n");
          Add(clashingLabels, SortedList([i, j]));
#          Print("Clashing labels: ", clashingLabels, ", ", SortedList([i, j]), "\n");
        fi;
      od;
    od;
  od;
od;
clashingLabels := Unique(SortedList(clashingLabels));
Print("\n\n\nClashing labels: ", clashingLabels, ".\n");
for i in [1 .. nLabels] do
  Print("\nLabel ", i, " is at ", labels[i], ".\n");
od;
#
Print("\nDone.\n");
